#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXfXfXgXjXlXlXlXlXlXlXlXlXlXlXlXlXkXgXfXfXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXdXfXjXlXlXlXlXlXlXlXlXlXlXlXlXjXgXfXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXNXHXLXGXbXkXlXlXlXlXlXlXlXlXlXlXkXzXAXKXKXZXlXkXlXlXlXlXlXlXlXlXlXlXlXlXkXCXPXLXNXjXlXlXlXlXlXlXlXlXlXlXjXmXHXLXGXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXbX/.>.| 8.&XmXkXlXlXlXlXlXlXlXlXkXnXiXx.o.+.N.gXvXkXlXlXlXlXlXlXlXlXlXlXjXnXF.^ ] ^.BXhXlXlXlXlXlXlXlXlXkXMX|.2.| 3.@XMXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX,.        = S.NXjXlXlXlXlXlXlXkXvX0XB         H rXcXkXlXlXlXlXlXlXlXlXkXbX<X=     i.GXfXlXlXlXlXlXlXlXhXVXx.@       $ N.mXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXVXG.  . a.{.|   u uXxXkXlXlXlXlXlXkXMX&.  k !.K.r   9.SXgXlXlXlXlXlXlXlXlXjXMX(   =   l.FXgXlXlXlXlXlXlXjXMX*X:   4.oX#.  , qXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX}.0.T.FXUX:X% : ;XnXjXlXlXlXlXlXkXbX! < ^.FXLXt.  ~ cXkXkXlXlXlXlXlXlXhXVXR.  T A   l.FXgXlXlXlXlXlXlXhXZX~.4 T BXAXuXr   `.mXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXZXmX1X.X)   ` vXkXlXlXlXlXlXlXlXlXuXtXhXfXZXO.  +.CXhXlXlXlXlXlXlXjXcXaXj   +X(   z.FXgXlXlXlXlXlXlXlXzXgXrXpXhXnX*X- . -XbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXhXr     Z rXmXjXlXlXlXlXlXlXlXlXcXcXhXCXU.o O {.BXhXlXlXlXlXlXlXjXVXy.  W UXJ   l.SXgXlXlXlXlXlXlXlXlXzXvXlXcXhXQ   _ vXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXlXA.0.x   R rXxXkXlXlXlXlXlXlXlXkXhXBXE.&   j.BXjXlXlXlXlXlXlXkXnX-X& < 4XUXU   M.UXgXlXlXlXlXlXlXlXlXlXgXcXgX'   h 9XvXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXfXpXjXnXMX3Xe   v.FXgXlXlXlXlXlXlXlXjXVXP.+   t.vXhXlXlXlXlXlXlXlXkXmX(   | $X2XB   2.eXgXlXlXlXlXlXlXlXlXjXbXsX~   s ;XbXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSXt.f i.SXVXhXl   y.JXfXlXlXlXlXlXlXkXBXS.O   z.GXBXmXzXlXlXlXlXlXlXlXlX=           +   c lXzXlXlXlXlXlXlXjXnXyXU   n 0XGXMXvXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXj.    =.D.R   & [.NXhXlXlXlXlXlXkXnXC.$   C S.V.b.R.fXzXlXlXlXlXlXlXlX4...#.$.=.e   z B.jXlXlXlXlXlXlXkXcXeXP   ; 4.H.m.M.-XcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX>.#       1 z.NXjXlXlXlXlXlXlXkXmXp             e qXvXkXlXlXlXlXlXlXcXcXcXlXFXc   s.KXfXlXlXlXlXlXlXgXSXK.              i.VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXMX{.s.9.z.:XBXkXlXlXlXlXlXlXlXlXcXm.3.6.5.5.7.1.x.aXxXkXlXlXlXlXlXlXlXlXlXjXnXN.-..XMXjXlXlXlXlXlXlXjXmX;X6.7.5.4.6.6.4. XbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXHXKXFXnXjXlXlXlXlXlXlXlXlXlXkXDXLXKXLXLXKXPXFXzXlXlXlXlXlXlXlXlXlXlXlXlXkXSXIXMXjXlXlXlXlXlXlXlXlXkXnXLXKXKXLXLXLXLXNXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXfXfXgXjXlXlXlXlXlXlXlXlXlXlXlXgXfXfXfXfXfXfXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXdXjXlXlXlXlXlXlXlXlXlXlXkXfXfXfXfXfXfXfXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXBXBXMXlXlXlXlXlXlXlXlXlXlXlXkXbXNXCXCXNXvXkXlXlXlXlXlXlXlXlXlXlXlXjXvXBXVXNXzXlXlXlXlXlXlXlXlXlXlXkXzXmXBXCXVXNXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX$Xg 0 L gXxXlXlXlXlXlXlXlXlXkXmX$X| p d #.,XnXjXlXlXlXlXlXlXlXlXlXkXBX1XW 5 A 8XcXkXlXlXlXlXlXlXlXkXxXlXG.P e v y.uXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXbXT     r fXxXlXlXlXlXlXlXlXkXbX@X2   6 :   8 =XMXjXlXlXlXlXlXlXlXjXnXY.>     1 3XvXjXlXlXlXlXlXlXlXjXmX5.    q O   K gXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCXA.  8   f fXxXlXlXlXlXlXlXlXkXmX!   ^ 4X:XA   &.ZXhXlXlXlXlXlXlXkXjXBXj % &.O 9 5XvXkXlXlXlXlXlXlXjXMX$X$   c.9XW.8   W.MXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXeXu # x.  f fXxXlXlXlXlXlXlXlXkXvX>.G #XCXKXa.  ~ xXkXkXlXlXlXlXlXlXlXzX9.;X|.  8 5XvXkXlXlXlXlXlXlXkXcXtX].XXSXUXgXl   Y.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4.  5.%X  g fXxXlXlXlXlXlXlXlXlXlXmXBXlXhXnXE   1.SXgXlXlXlXlXlXlXlXlXkXcXGXW.  8 5XvXkXlXlXlXlXlXlXlXlXxXmXBX{.i.W + ` sXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXOXX > 8X+X  f iXlXlXlXlXlXlXlXlXlXlXkXhXjXNXr.  9 3XnXjXlXlXlXlXlXlXlXlXlXgXVX!.  8 5XvXkXlXlXlXlXlXlXlXlXkXdXMX@.    4 Q.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXxXL   A.UX;X  l AXMXkXlXlXlXlXlXlXlXlXkXlXmXy.  $ ^.NXjXlXlXlXlXlXlXlXlXlXlXhXCX!.  8 5XvXkXlXlXlXlXlXlXlXkXcXmXmX1X`.0.% O K.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXH.  , 9.k.=.  5 p.1XbXkXlXlXlXlXlXlXkXxXnX8.  & E.NXhXlXlXlXlXlXlXlXlXlXlXlXhXCX!.  8 5XvXkXlXlXlXlXlXlXkXcXtX$X2XNXbXSX$.  P SXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXFXd.          o     J.ZXgXlXlXlXlXlXlXlXzX<.  : ^.DXxXcXlXlXlXlXlXlXlXlXlXlXlXhXCX!.  8 5XvXkXlXlXlXlXlXlXhXSXI.$ n 6XmXgX!   Y SXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX*Xj.m.N.F.1.  > M.7XvXkXlXlXlXlXlXkXmX6.  . v ,.$.O.p.aXxXkXlXlXlXlXlXlXlXlXhXCX~.o w 6XvXkXlXlXlXlXlXlXjXbX3Xr   y =.A     L.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXBXNXmXKX].  e cXbXkXlXlXlXlXlXlXkXmXa             0 qXvXkXlXlXlXlXlXlXlXlXgXZXT.  * 4XvXjXlXlXlXlXlXlXlXhXBXoXG .     s n.nXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXzXrX!. XhXlXlXlXlXlXlXlXlXlXzX@X/.)._.`.`.).OXgXzXlXlXlXlXlXlXlXlXlXkXcXrX).{.fXzXlXlXlXlXlXlXlXlXlXjXBXdX+X]. X0XVXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXAXVXlXlXlXlXlXlXlXlXlXlXlXBXAXZXZXZXZXAXBXzXlXlXlXlXlXlXlXlXlXlXlXkXcXZXCXzXlXlXlXlXlXlXlXlXlXlXlXhXzXBXZXVXvXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXjXlXlXlXlXlXlXlXlXlXlXlXjXhXhXhXhXhXhXjXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXjXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXhXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXSXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXZXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX^.9.s.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.p.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.i.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.t.j.lXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXh.v J Z A A A A A A A A A A A A A A S F Z A A A A A A A A A A A A A A A S P U U U U U U U U U U U U U U U Y K P U U U U U U U U U U U U U U U L ! kXzXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXjXjXkXlXlXlXlXlXlXhXAXn.G { *.$.%.%.%.%.%.%.%.%.%.%.%.$.%.+.` &.$.%.%.%.%.%.%.%.%.%.%.%.%.$.%.+.C j z z z z z z z z z z z z z z h J N k z z z z z z z z z z z z z x g _ zXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXVXVXVXVXVXVXvXkXlXlXlXlXlXgXSXb.C @.l.d.f.f.f.f.f.f.f.f.f.f.f.f.h.r.X.l.d.f.f.f.f.f.f.f.f.f.f.f.f.d.h.r.5                                 j :                                 U vXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXiX XXXoXoXoXoXqXcXkXlXlXlXlXgXSXb.Z O.s.y.u.u.u.u.u.u.u.u.u.u.u.u.p.9. .s.y.u.u.u.u.u.u.u.u.u.u.u.u.y.p.9.q   o X X X X X X X X X X X X o   z 3   X X X X X X X X X X X X X o   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXR.            s.FXgXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXC.  h O.X.o.O.].NXjXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXf.  3.UXIXHXbXlXlXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX3.  p.U.,.v.yXbXkXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX^   1 $     N 5XbXjXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXa.z ~ '.!.s   #.CXhXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXKXGXMXvXHXA.  z eXvXkXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXH.v.0XmXZXQ.  k qXvXkXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXb   O.qXqXQ   _ MXjXkXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX!.#   e 0   4 @XNXhXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX[.^ 9 w ..;XmXjXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXmXMXMXmXbXjXlXlXlXlXlXlXgXSXb.Z O.d.u.i.i.i.i.i.i.i.i.i.i.i.u.a.0. .d.u.i.i.i.i.i.i.i.i.i.i.i.i.u.p.9.0   X . . . . . . . . . . . . X   z 2   . . . . . . . . . . . . . X   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXlXlXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.q.7                                 k ,                                 Y vXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXSXb.Z O.s.y.u.u.u.u.u.u.u.u.u.u.u.u.p.9. .s.y.u.u.u.u.u.u.u.u.u.u.u.u.y.p.7.a - 1 , , , , , , , , , , , , 1 * m t ; < , , , , , , , , , , , , 1 * W cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXSXc.H L d j h h h h h h h h h h h h g x J d j h h h h h h h h h h h h j d B F l c c c c c c c c c c c c c c l H B z c c c c c c c c c c c c c v j ( zXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXfXfXfXfXfXjXlXlXlXlXlXlXgXSXx.P n                               @ v                                 8 u                                 j ;                                 U vXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXKXKXKXKXKXKXMXkXlXlXlXlXlXgXSXx.L M   o X X X X X X X X X X X X   - m   o X X X X X X X X X X X X o   e s   o X X X X X X X X X X X X o   z 3   X X X X X X X X X X X X X o   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX5Xt.i.i.i.i.y.@XmXjXlXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXL.            s.FXgXlXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXN.  J M.b.b.n.;XbXkXlXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXi.  r.UXUXPXAXxXlXlXlXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX>.  3.-.j ] OXnXjXlXlXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXR   . w -   <  XNXhXlXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXQ.-.d.qX6XL   ~ nXjXkXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXFXLXCXkXAXR.  h 9XbXjXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX7.{ &XZXGXH.  b yXcXkXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXG   V ]._.k   =.ZXhXlXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX>Xg         Z qXvXkXlXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXqXi._ ' c.fXvXkXlXlXlXlXlXgXSXx.L M   X                           = n   X                         .   w s   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXSXKXKXZXzXkXlXlXlXlXlXlXgXSXx.L M   o . . . . . . . . . . . X   - m   o . . . . . . . . . . . . o   e s   o . . . . . . . . . . . . o   z 3   X . . . . . . . . . . . . o   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXfXfXhXlXlXlXlXlXlXlXlXgXSXx.P b                               + n                                 q y                                 h 1                                 Y vXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXSXc.J J r p i i i i i i i i i i i i y j B # ; - - - - - - - - - - - - ; $ u C e p i i i i i i i i i i i i p e D 9 % - - - - - - - - - - - - - ; @ E cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXSXc.J H q t t t t t t t t t t t t t y 9 6.wX>X<X<X<X<X<X<X<X<X<X<X<X<X,X8XQ.d e t t t t t t t t t t t t t y w v  X5X,X<X<X<X<X<X<X<X<X<X<X<X<X,X5X2.dXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXfXgXlXlXlXlXlXlXlXlXlXlXlXhXfXgXkXlXlXlXlXlXlXgXSXx.P b                                 k.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXyX*                                 q VXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXr.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXjXxXDXKXFXxXlXlXlXlXlXlXlXlXkXzXSXKXFXxXlXlXlXlXlXlXgXSXx.L M   o . . . . . . . . . . . X X   d.UXGXLXLXLXLXLXLXLXLXLXLXLXLXHXUX5X<   o . . . . . . . . . . . . o   y jXUXJXLXLXLXLXLXLXLXLXLXLXLXLXJXUXq.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXNXuX=.B | rXxXkXlXlXlXlXlXkXMXsX<.V ` 9XcXkXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXvX|.a     < 6XvXjXlXlXlXlXkXvX@Xl     % ,XbXjXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXjXNXj   ! o t 8XcXkXlXlXlXlXhXCXZ   ~ $ 6 2XvXkXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXlXzXX.'.`.  e 9XcXkXlXlXlXkXkXvX%.E.oXo 3 2XvXjXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXfXKXU.  e 9XcXkXlXlXlXlXlXkXdXHX(.. 4 2XvXjXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXhXVXY.  e 9XcXkXlXlXlXlXlXlXjXBX(.X 4 2XvXjXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXgXZXT.  e 9XcXkXlXlXlXlXlXlXhXCX).X 4 2XvXjXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXhXZXT.  e 9XcXkXlXlXlXlXlXlXhXCX).X 4 2XvXjXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXhXZXT.  e 9XcXkXlXlXlXlXlXlXhXCX).X 4 2XvXjXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXhXZXR.. u 9XcXkXlXlXlXlXlXlXhXCX_.# 8 2XvXkXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXgXAXJ.  = 7XvXjXlXlXlXlXlXlXhXZX!.  X ,XbXjXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXkXbX2Xk.Z.aXzXkXlXlXlXlXlXlXkXbX6Xx.B.iXxXkXlXlXlXlXgXSXx.L M   X                         .   f.UXKXUXUXUXUXUXUXUXUXUXUXUXUXLXUX7X>   X                         X   t lXUXPXUXUXUXUXUXUXUXUXUXUXUXUXPXUXw.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXJXFXxXlXlXlXlXlXlXlXlXlXkXbXHXFXxXlXlXlXlXlXlXgXSXx.L M   o X X X X X X X X X X X X o   d.UXFXKXKXKXKXKXKXKXKXKXKXKXKXGXUX4X<   o X X X X X X X X X X X X o   y hXUXJXKXKXKXKXKXKXKXKXKXKXKXKXHXUXq.aXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXgXlXlXlXlXlXlXlXlXlXlXlXkXgXgXkXlXlXlXlXlXlXgXSXx.P n                                 l.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXpX*                                 q AXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXt.pXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXSXc.H I l c x x x x x x x x x x x x x l O.b.k.l.l.l.l.l.l.l.l.l.l.l.l.k.c.w.B v b b b b b b b b b b b b b n c S d.b.x.c.c.c.c.c.c.c.c.c.c.c.c.x.c.$.hXzXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.w.' 1.>.,.,.,.,.,.,.,.,.,.,.,.,.>.,.-.p % : ; ; ; ; ; ; ; ; ; ; ; ; > # m ;                                 Y vXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXzXlXlXlXlXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0.X.l.d.f.f.f.f.f.f.f.f.f.f.f.f.d.h.e.7                                 k 3   X . . . . . . . . . . . . X   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXxXlXlXlXlXlXlXlXlXlXlXgXSXb.Z O.d.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .d.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.0   X                         X   z 2   .                         X   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX$Xe * l yXcXkXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXbXW     8 tXvXkXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXVXF.  t   e tXvXkXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXtXi O Z.  w tXvXkXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX5.  <.4X  e tXvXkXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXNX+XO : 4X,X  e 0XxXlXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXzXU   A.UXwX  u MXVXjXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXY.  & o.,.}   : $.@XmXjXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSXC.  @       X     B.AXgXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX5XD.P.U.!.d.  = S.0XcXkXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXBXNXMXGX&X  7 gXmXkXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXkXaX$X:XgXlXlXlXlXlXlXlXgXSXb.Z +.f.u.i.i.i.i.i.i.i.i.i.i.i.i.a.0. .f.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.0.9   X                         X   z 2   .                         .   T cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXBXMXlXlXlXlXlXlXlXlXgXSXb.A +.f.i.p.p.p.p.p.p.p.p.p.p.p.p.s.q...f.i.p.p.p.p.p.p.p.p.p.p.p.p.i.a.q.q   o . . . . . . . . . . . . o   x 3   X . . . . . . . . . . . . o   R cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXkXlXlXlXlXlXlXlXlXgXSXx.m  .p.e.r.r.r.r.r.r.r.r.r.r.r.r.y.6.] p.e.r.r.r.r.r.r.r.r.r.r.r.r.e.y.6.3                                 d -                                 K cXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXD.` &.=.*.*.*.*.*.*.*.*.*.*.*.*.*.=.&.#.=.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.| ] [ [ [ [ [ [ [ [ [ [ [ [ [ [ ] ..} ] [ [ [ [ [ [ [ [ [ [ [ [ [ [ _ -.lXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXnXbXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXbXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXmXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXmXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXnXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXgXjXlXlXlXlXlXlXlXlXlXlXjXgXgXjXlXlXlXlXlXlXlXlXlXlXlXjXfXgXlXlXlXlXlXlXlXlXlXlXjXgXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXHXJXBXkXlXlXlXlXlXlXlXlXkXBXKXHXmXjXlXlXlXlXlXlXlXlXlXjXmXKXFXzXlXlXlXlXlXlXlXlXkXVXKXHXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXNXOX8.2.).nXlXlXlXlXlXlXlXzXmX).2.9.$XMXkXlXlXlXlXlXlXlXjXmX+X=.u.sXxXkXlXlXlXlXlXzXbXW.<.e.;XMXjXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXj.  # &   e.BXjXlXlXlXlXjXNXp.  ; o   I.VXhXlXlXlXlXlXkXlXlXz   & eXvXkXlXlXlXlXjXmX5.  >   # (.BXjXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXgXA m 9XsXs ; yXcXkXlXlXkXbXeX+ k dX&X@ v nXkXlXlXlXlXlXhXSXy.+ 9 5 tXvXkXlXlXlXjXmX2X  A lX X  J BXjXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdXzXkX$Xw Z kXlXkXlXlXlXxXsXI.-XZXcX9 h vXkXkXlXlXlXjXnX5X  ;./ # uXvXkXlXlXlXkXcXuXL.<XSXfX- A MXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXfXg   > @XVXhXlXlXlXlXlXxXZXvXVX0.  j.ZXhXlXlXlXlXjXCX/   sXR # rXcXkXlXlXlXlXkXxXZXvXBX=.  A.ZXhXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXZXnX_.k.7 h 0XvXkXlXlXlXlXkXgXBXy.  [ vXkXlXlXlXlXjXBXQ.  v.UXU & nXmXjXlXlXlXlXlXjXhXMX1.  *.nXkXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXiXj.`.IXUX6.  R.SXhXlXlXlXkXzXBX8.  #.SXVXlXlXlXlXlXhXCXn   m G <   U 9XvXkXlXlXlXkXxXmX=.  3.GXNXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXiX> . N.J.4 . *XMXjXlXlXlXlXcX4.  j /.~._.fXzXlXlXlXjXmX;.S C B <   J 9XvXkXlXlXkXlXlX%.  N `.Q.].hXzXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX_.r     1 B.MXjXlXlXlXkXnX5X          < 6XbXjXlXlXlXlXxXxXxXKXV   sXbXkXlXlXlXjXNX&X          q tXcXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXNXpXXX XeXBXkXlXlXlXlXlXzXfX.X[.].].].XXfXzXlXlXlXlXlXlXlXkXcX&X|.jXzXlXlXlXlXlXxXaX|.[.'.[.'.OXhXzXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXcXVXVXvXjXlXlXlXlXlXlXlXzXVXCXCXCXZXVXzXlXlXlXlXlXlXlXlXlXkXMXVXlXlXlXlXlXlXlXlXxXCXCXCXCXZXBXzXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXkXlXlXlXlXlXlXlXlXlXjXhXhXhXhXjXlXlXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXlXhXhXhXhXhXjXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXfXgXlXlXlXlXlXlXlXlXlXlXjXgXgXjXlXlXlXlXlXlXlXlXlXlXlXhXfXhXlXlXlXlXlXlXlXlXlXlXjXgXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnXKXGXxXkXlXlXlXlXlXlXlXkXVXKXJXmXjXlXlXlXlXlXlXlXlXlXjXCXLXCXkXlXlXlXlXlXlXlXlXkXBXJXJXNXkXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX%X@.3.tXcXkXlXlXlXlXlXzXnXW.*.<.XXMXkXlXlXlXlXlXlXkXxXCXH.} A.vXkXlXlXlXlXlXlXzXmX/.-.;.`.nXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXvXV   . 2XmXjXlXlXlXlXjXMXe.  1 $   H.VXhXlXlXlXlXlXlXkX|     T MXjXlXlXlXlXlXkXnX>.  > *   z.VXjXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXl.O y - 5XnXkXlXlXlXkXbXwX+ b kX:X% x bXkXkXlXlXlXkXmX=X5 r.$ ) MXkXlXlXlXlXkXvXeXx ! jXtX2 y kXzXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXwX@ o.@.  8XnXjXlXlXlXlXxXsXQ.>XCXxX7 k vXkXkXlXlXlXlXcXeXqX0X  ( NXkXlXlXlXlXlXlXkXjXcXaX^.> ' nXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXAX..  tXX.  5XnXkXlXlXlXlXlXxXCXvXVX3.  c.ZXhXlXlXlXlXlXkXzXZX=X  ( NXkXlXlXlXlXlXlXkXzXqX4   q 3XMXjXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX].  i.UX|   fXBXjXlXlXlXlXlXkXhXNX8.  o.bXkXlXlXlXlXlXlXlXhXnX:X  ( NXkXlXlXlXlXlXkXxXAXzX].k.> M pXxXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXK   h B 2   N ,XnXjXlXlXlXkXzXNX1.  :.FXVXlXlXlXlXlXlXlXlXjXMX:X  ( NXkXlXlXlXlXkXbX9Xe. XUXUX{   +XVXjXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXw.L J J 6   F 3XbXjXlXlXlXlXxX:.  j E.I.Q.dXzXlXlXlXlXlXlXjXMX:X. ) NXkXlXlXlXlXjXnX5X  * C.x.O 2 0XbXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXvXcXUX!   wXMXjXlXlXlXkXnX5X          < 6XbXjXlXlXlXlXlXjXMX;X  W NXjXlXlXlXlXlXjXNXR.q     y ~.MXjXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXxX1XOXgXzXlXlXlXlXlXzXgX$XOXXXOXoX%XgXzXlXlXlXlXlXlXlXzXdXoX1XxXlXlXlXlXlXlXlXkXBXpX$X%XsXNXkXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXBXzXlXlXlXlXlXlXlXzXBXBXBXVXVXNXzXlXlXlXlXlXlXlXlXlXzXBXmXlXlXlXlXlXlXlXlXlXjXcXBXBXxXjXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXlXlXlXlXlXlXlXlXlXjXjXjXjXjXjXlXlXlXlXlXlXlXlXlXlXlXjXkXlXlXlXlXlXlXlXlXlXlXkXjXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXbXvXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXvXbXzXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtX0XwXwXwXwXwXwXwXwXwXwXwXwXwXqXwXwXwXwXwXwXwXwXwXwXwXwXwX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XgXzXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX4.K R Y Y Y Y Y Y Y Y Y Y Y T R Y Y Y Y Y Y Y Y Y Y Y Y Y ~ / / / / / / / / / / / / ~ ~ / / / / / / / / / / / _ P OXNXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXgXgXgXgXkXlXlXlXlXjXBX4.L o.X...................o.[ ' o.....................X.| C x v v v v v v v v v v x Z A x v v v v v v v v v v b x #XNXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXGXKXLXLXKXvXkXlXlXlXjXBX4.I d.f.d.d.d.d.d.d.d.d.d.j.6.,.k.s.d.d.d.d.d.d.d.d.d.g.y.1                         4 6                         % *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXwX@.) ( ^ ] 2XnXkXlXlXjXBX4.I u.i.u.u.u.u.u.u.u.u.u.a.3.-.s.y.u.u.u.u.u.u.u.u.y.i.q.6   o . . . . . . . . X   9 q   X . . . . . . . . X   ; &XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXOX  % y 0 s =XMXjXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX(.  P.UXZXbXkXlXlXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXZ.  3.W ( @XmXjXlXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXb.  s ~ . $ ;XmXjXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxX9XeXKXP.  7.CXhXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX(.j.gXIX%X  ;.CXjXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSXh.  ! /.Z   (.BXjXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxX3.#   > k.nXkXlXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXNX0X:XtXBXlXlXlXlXlXjXBX4.I y.i.u.u.u.u.u.u.u.u.y.a.2.-.s.y.u.u.u.u.u.u.u.u.y.i.q.6   o . . . . . . . . X   9 q   X . . . . . . . . X   ; &XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXbXMXvXjXlXlXlXlXlXjXBX4.I d.g.f.f.f.f.f.f.f.f.f.k.7.,.l.d.f.f.f.f.f.f.f.f.d.h.y.1                         4 6                         % *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXkXlXlXlXlXlXlXjXBX4.L @.@.+.+.+.+.+.+.+.+.+.#.| [ #.+.+.+.+.+.+.+.+.+.+.@.o.b p d d d d d d d d d d p n m p d d d d d d d d d d d d $XNXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXgXgXgXgXkXlXlXlXlXjXNX6.G #   . . . . . . . . X   4 t   X . . . . . . . . X   6 a @ - = = = = = = = = - # y u # - = = = = = = = = - & 3 &XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXGXJXKXKXJXvXkXlXlXlXjXNX6.F +                       3 r   .                     6 0                         6 8                         * *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX0X{ R Y U Q 1XnXjXlXlXjXNX6.G @   .               .   4 r   X                 .   6 w   X                 .   8 0   .                 .   - &XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXoX  ; g i l ;XmXjXlXlXjXNX6.G @                   .   4 r   .                 .   6 w   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX/.  Y.UXSXMXkXlXlXlXlXjXNX6.G @                   .   4 r   .                 .   6 w   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXC.  :.J T  XmXjXlXlXlXjXNX6.G @                   .   4 r   .                 .   6 w   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXm.  h [ + O *XmXjXlXlXjXNX6.G @                   .   4 r   .                 .   6 w   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXtXuXLXT.  5.CXjXlXlXjXNX6.G @                   .   4 r   .                 .   6 w   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX!.y.sXUX#X  :.CXjXlXlXjXNX6.G @                   .   4 r   .                 .   6 w   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSXl.  I Y.n   `.BXjXlXlXjXNX6.G @                   .   4 r   .                 .   6 w   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXq.=   4 n.mXkXlXlXlXjXNX6.G @                   .   4 r   .                 .   6 w   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXNXtX4XpXBXlXlXlXlXlXjXNX6.G #   . . . . . . . . X   4 t   o X X X X X X X X o   7 e   X . . . . . . . . X   9 q   o X X X X X X X X o   ; &XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXvXmXcXjXlXlXlXlXlXjXNX6.F .                       < 9                         , 9                         5 4                         @ *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXjXNX5.J k d f f f f f f f f f s v F b M m m m m m m m m M b S M a f f f f f f f f f f a n D b M m m m m m m m m M M v #XNXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXhXgXhXlXlXlXlXlXlXlXlXjXgXhXlXlXlXlXlXjXNX5.G : % & & & & & & & & & & $ +XUXHXLXLXLXLXLXLXLXLXJXUXtX4 # * & & & & & & & & * % ; 1XUXJXLXLXLXLXLXLXLXLXJXUX+X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXCXHXZXlXlXlXlXlXlXlXkXVXHXAXlXlXlXlXlXjXNX6.F o                         $XUXPXUXUXUXUXUXUXUXUXIXUXiX;                         + 5XUXIXUXUXUXUXUXUXUXUXIXUX#X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXVXV.A 3.lXlXlXlXlXlXlXCXG.D ;.hXzXkXlXlXjXNX6.G @                   .   . #XUXKXIXIXIXIXIXIXIXIXLXUXuX>   .                 .   # 4XUXLXIXIXIXIXIXIXIXIXLXUX@X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXkXvX|     h kXlXkXlXlXjXnX&.    t fXzXkXlXlXjXNX6.G @                   .     #XUXLXUXUXUXUXUXUXUXUXPXUXuX:   .                 .   # 4XUXLXUXUXUXUXUXUXUXUXLXUX#X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXkXcXyXk v.w b zXlXkXlXkXzXfXc l.s d gXzXkXlXlXjXNX6.G @                   .     #XUXLXUXUXUXUXUXUXUXUXPXUXuX:   .                 .   # 4XUXLXUXUXUXUXUXUXUXUXLXUX#X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXzXsXiXlX2 v zXlXkXlXlXzXfXtXnXe a hXzXkXlXlXjXNX6.G @                   .     #XUXLXUXUXUXUXUXUXUXUXPXUXuX:   .                 .   # 4XUXLXUXUXUXUXUXUXUXUXLXUX#X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXMXtX2 v zXlXkXlXlXlXlXnXsXw s gXzXkXlXlXjXNX6.G @                   .     #XUXLXUXUXUXUXUXUXUXUXPXUXuX:   .                 .   # 4XUXLXUXUXUXUXUXUXUXUXLXUX#X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXcXuX2 v zXlXkXlXlXlXkXzXfXw a gXzXkXlXlXjXNX6.G @                   .     #XUXLXUXUXUXUXUXUXUXUXPXUXuX:   .                 .   # 4XUXLXUXUXUXUXUXUXUXUXLXUX#X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXvXuX3 v zXlXkXlXlXlXkXxXfXe s gXzXkXlXlXjXNX6.G @                   .     #XUXLXUXUXUXUXUXUXUXUXPXUXuX:   .                 .   # 4XUXLXUXUXUXUXUXUXUXUXLXUX#X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXvXuX1 c zXlXkXlXlXlXkXxXfXq p gXzXkXlXlXjXNX6.G @                   .     #XUXLXUXUXUXUXUXUXUXUXPXUXuX:   .                 .   # 4XUXLXUXUXUXUXUXUXUXUXLXUX#X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXvXuX6 m zXlXkXlXlXlXkXxXfXy g hXzXkXlXlXjXNX6.G @                   .     #XUXLXUXUXUXUXUXUXUXUXPXUXuX:   .                 .   # 4XUXLXUXUXUXUXUXUXUXUXLXUX#X_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXkX0XeXlXlXlXlXlXlXlXlXlXqXwXlXlXlXlXlXjXNX6.G # . X X X X X X X X X . X +XUXHXLXLXLXLXLXLXLXLXJXUXtX>   X . . . . . . . . X   $ 1XUXHXKXKXKXKXKXKXKXKXHXUXOX_.CXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXbXvXlXlXlXlXlXlXlXlXlXbXvXlXlXlXlXlXjXNX6.F                           >XUXUXUXUXUXUXUXUXUXUXUXUXlX*                         X yXUXUXUXUXUXUXUXUXUXUXUXUX<X(.ZXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXjXBX5.J M b b b b b b b b b b b v q.A.M.N.N.N.N.N.N.N.N.M.C.f.c d h g g g g g g g g g f l q.c.k.l.l.l.l.l.l.l.l.k.n.,. XBXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXhXlXlXlXlXlXlXjXBX4.I d.f.d.d.d.d.d.d.d.d.d.j.8.+.7.3.3.3.3.3.3.3.3.3.3.4.<.q o % $ $ $ $ $ $ $ $ % X r 2                         + *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmXFXSXzXlXlXlXlXlXjXBX4.I u.i.u.u.u.u.u.u.u.u.u.s.2.>.j.s.d.d.d.d.d.d.d.d.s.f.t.3                         6 w   o X X X X X X X X o   ; &XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXVXW.N / rXvXkXlXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - &XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXpXt   % 8XbXkXlXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSX;.- j ; qXbXkXlXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX&X  y...  eXbXkXlXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXNXS * MX( X eXbXkXlXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXA.  N.UXQ o uXnXkXlXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXb   1 < #   e >XmXjXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXv.*.*.>.e   %.eXcXkXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXVXMXUX( - fXmXjXlXlXlXjXBX4.I u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.5   .                 .   8 0   .                 .   - *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXjXjXkXiXrXhXlXlXlXlXlXjXBX4.U u.p.i.i.i.i.i.i.i.i.u.s.3.;.d.u.i.i.i.i.i.i.i.i.u.p.w.7   o X X X X X X X X o   0 w   o X X X X X X X X o   : *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXvXlXlXlXlXlXlXjXBX1.J u.p.i.i.i.i.i.i.i.i.u.d.2.=.f.u.i.i.i.i.i.i.i.i.u.a.w.;                         < 2                         O &XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXjXNXt._ <.,.,.,.,.,.,.,.,.,.>.<.=.%.<.>.,.,.,.,.,.,.,.,.>.,.:.T G J H H H H H H H H J F R E F J H H H H H H H H J J G *XMXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXfXfXfXfXfXfXfXfXfXfXfXfXgXhXfXfXfXfXfXfXfXfXfXfXfXfXgXcXbXvXvXvXvXvXvXvXvXvXvXbXxXxXbXvXvXvXvXvXvXvXvXvXvXbXcXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXkXkXkXkXkXkXkXkXkXkXkXkXlXlXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXhXkXlXlXlXlXlXlXlXlXlXjXhXjXlXlXlXlXlXlXlXlXlXlXlXhXhXlXlXlXlXlXlXlXlXlXkXhXhXkXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXcXSXSXcXjXlXlXlXlXlXlXlXjXNXFXBXjXlXlXlXlXlXlXlXlXlXlXAXSXxXlXlXlXlXlXlXlXjXbXDXZXzXkXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXNXuXU.I.rXMXkXlXlXlXlXlXzXMX+XD.XXnXzXlXlXlXlXlXlXlXzXjXR.P.pXxXkXlXlXlXlXkXNX6XJ.!.hXbXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX[.< X . 7 +XmXjXlXlXlXjXmX9.  *   =.nXkXlXlXlXlXlXhXAXb.    ;XMXjXlXlXlXjXMX~.= $   m rXvXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX%.d 8X4X  ) AXjXlXlXjXmX1X  ..vX&.  &XMXjXlXlXlXkXvX0X7 8 * ,XmXjXlXlXlXkXmXh w iXY.  s.SXhXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXcX7XC.< z.VXjXlXlXkXcXiX).eXUXx.  $XMXjXlXlXlXhXSX) a s.  <XmXjXlXlXlXlXlX}.;XKX3X  u.SXhXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXjXN   f wXbXkXlXlXlXkXxXMXAX&X. Y mXkXlXlXlXhXCX[.  '.D.  6XMXjXlXlXlXlXlXMXBXjXb : 0XbXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXvXiXoX3 V nXkXlXlXlXlXhXBX#X@ h aXvXkXlXlXkXzXlXg h nXt.  +XvXkXlXlXlXlXjXvXfXB    XBXjXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX` [ MXAXz - lXzXlXlXlXjXMXOX- M zXAXzXlXlXlXjXMX-X  + + +   2 1XnXjXlXlXkXcXpXZ % %XKXxXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXw.  u y   y.NXjXlXlXjXnX4Xo   g Z j ~.NXjXlXlXxXaXQ.U.'.'   M.kXlXlXlXlXkXmXZ   3 F a e.MXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXNXQ. . .T.bXzXlXlXlXkXnX3X..o._ ^ Q [.MXjXlXlXlXxXVXNXLX_.[ dXnXkXlXlXlXlXzX6.} [ / T c.nXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXBXJXJXVXkXlXlXlXlXlXkXvXHXHXJXKXLXmXkXlXlXlXlXlXjXjXgXmXHXlXkXlXlXlXlXlXlXDXHXJXKXPXZXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXgXjXlXlXlXlXlXlXlXkXgXgXgXgXgXkXlXlXlXlXlXlXlXlXlXjXfXlXlXlXlXlXlXlXlXhXfXgXgXfXhXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXhXlXlXlXlXlXlXlXlXkXhXgXhXkXlXlXlXlXlXlXlXlXlXjXgXhXlXlXlXlXlXlXlXlXlXhXgXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmXHXZXlXlXlXlXlXlXlXkXcXDXJXDXvXkXlXlXlXlXlXlXlXjXNXHXZXlXlXlXlXlXlXlXlXlXVXHXHXBXkXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXBX(.D 4.cXlXlXlXlXlXjXbXyX3.F :.0XbXkXlXlXlXlXlXjXCX/.H 3.zXlXlXlXlXlXlXlXmXH.Y W R.nXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXfXi   j bXkXlXlXlXkXzXhXc   ~ X g fXxXkXlXlXlXhXCXl.    f zXlXkXlXlXlXjXVX5.  C x   K.VXjXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXDX>.8 j l mXkXlXlXlXjXmX,Xr A.UXM.  }.BXjXlXlXlXjXVX6.Z.A l cXlXkXlXlXlXlXvXg.d.UXzX  ..SXhXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX;X  B.E u bXkXlXlXlXlXlXlXkXlXFX+.  7XbXkXlXlXlXlXkXxXFXz j cXlXkXlXlXlXlXkXVXMXw.n a ;XnXjXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXBXG v UXG h PXkXlXlXlXlXlXkXkXAXs.  s.VXjXlXlXlXlXlXlXlXvXx j cXlXkXlXlXlXlXlXnXhX{ 8 e ].nXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXP.  ( A.t 1 Y.zXlXlXlXlXkXlXZXy.  r.GXzXkXlXlXlXlXlXlXkXnXx j cXlXkXlXlXlXlXlX$X8XUXBXq e MXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXV.7 r 1 %   ~ vXlXlXlXlXkXvXe.  [ 0X=XuXxXlXlXlXlXlXlXlXnXv z cXlXkXlXlXlXlXbXl 8 +X'.+ n MXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhXiXiXNXj 7 vXkXlXlXlXjXMX&X    $ X   S.CXhXlXlXlXlXlXlXmXa y cXlXkXlXlXlXjXMX/.3     r oXmXjXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXxXnX+XXXvXlXlXlXlXkXxXiX`.).~.^.!.9XcXkXlXlXlXlXlXlXzXXXXXzXlXlXlXlXlXlXkXBXuX'.[.sXMXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXjXNXBXkXlXlXlXlXlXkXxXCXCXZXAXAXbXkXlXlXlXlXlXlXlXlXBXBXlXlXlXlXlXlXlXlXjXcXCXCXxXjXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXhXhXhXhXhXkXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXlXkXhXhXkXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXxXxXxXxXxXxXxXxXxXxXxXcXxXxXxXxXxXxXxXxXxXxXxXcXxXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXtX&.@.+.+.+.+.+.+.+.+.+.+.+.@.+.+.+.+.+.+.+.+.+.+.+.+.*.-.=.=.=.=.=.=.=.=.=.-.&.=.-.=.=.=.=.=.=.=.=.:.X.G.VXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXgXgXgXjXlXlXlXkXvXwXU W ' _ _ _ _ _ _ _ _ ` ) Q ` _ _ _ _ _ _ _ _ _ ` ( M x v c c c c c c c v x A b c c c c c c c c v n p k.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXFXGXHXJXNXkXlXlXkXvXrXR =.k.d.f.f.f.f.f.f.f.g.p.=.h.d.f.f.f.f.f.f.f.d.g.r.:                       p o                       j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX#XG C B l V.VXhXlXkXvXrXT $.d.y.u.u.u.u.u.u.u.i.r.%.a.u.u.u.u.u.u.u.u.u.p.9.1   X . . . . . . . X   s #   . . . . . . . . o   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCXA.  P } Y J.BXjXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXg.< aXgXAXCXjXlXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDX&.  m   x ,XnXjXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX`.O.L.E.  R BXjXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzX0XpXKXUXQ q gXxXkXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXhXDX..  ).XXo T VXjXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX1Xz   . j ,XnXjXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXkXXX XhXmXjXlXlXkXvXrXR $.s.y.y.y.y.y.y.y.y.u.e.%.p.y.y.y.y.y.y.y.y.y.i.9.<   X . . . . . . . X   s #   . . . . . . . . o   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXzXVXVXzXjXlXlXlXkXvXrXT =.x.g.h.h.h.h.h.h.h.j.s.-.l.g.h.h.h.h.h.h.h.g.k.t.>                       p O                       j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXhXjXlXlXlXlXkXvXeXQ Q ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ~ ! ^ ^ ^ ^ ^ ^ ^ ^ ^ ^ ~ / c a d d d d d d d d d a C h s d d d d d d d d g 0 z.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXbXbXnXnXcXlXlXlXkXvXqX_ u                       i                       1 0   O o o o o o o o O   d % . o o o o o o o o +   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXgX9X9X9X8XpXzXlXlXkXvXqX_ a   o . . . . . . .   @ s   X . . . . . . . X   7 6                       a @                   .   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX~.  X .   r.SXhXlXkXvXqX_ a   .                 + s   .               .   6 7   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXN.  G.@XQ.;XvXkXlXkXvXqX_ a   .                 + s   .               .   6 7   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXhXAXe.: /.x.;XZXjXlXlXkXvXqX_ a   .                 + s   .               .   6 7   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSX:.  v <   H.VXhXlXkXvXqX_ a   .                 + s   .               .   6 7   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpXXXtXhXt l vXlXkXkXvXqX_ a   .                 + s   .               .   6 7   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXH.Z.DXIXK t kXzXkXkXvXqX_ a   .                 + s   .               .   6 7   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSX5.  O.;.  5.ZXhXlXkXvXqX_ a   .                 + s   .               .   6 7   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXu.y r q.kXzXkXlXkXvXqX_ a   X                 @ s   .               .   6 7   .               .   s #                 . X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXVXNXMXCXzXkXlXlXkXvXqX_ i                     X s   o X X X X X X X o   7 5                       p $   X X X X X X X X O   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXkXkXjXkXlXlXlXkXvXqX) j # - = = = = = = = * < p                       > y # - = = = = = = = - % g                         h.SXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXhXgXkXlXlXlXlXlXlXlXhXgXkXlXlXlXkXvXwX/ N r i u u u u u u u i 0 =./.U.T.T.T.T.T.T.T.Y.Q.m.f y i u u u u u u u i q P E.T.T.T.T.T.T.T.T.T.W.C.V.VXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXkXAXHXvXkXlXlXlXlXkXkXAXHXvXkXlXlXkXvXqX_ u                       k.UXUXUXUXUXUXUXUXUXUXUXhX@                       G UXUXUXUXUXUXUXUXUXUXUXPXH.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXkXcXNXL.g.7XvXkXlXlXkXcXBXP.f.6XvXkXlXkXvXqX_ s   o . . . . . . . O   s.UXGXKXKXKXKXKXKXKXHXUX0X=   X . . . . . . . O   H UXKXKXKXKXKXKXKXKXKXUXbXG.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXkXzXdXQ     ~.BXjXlXkXzXfX~     Q.VXjXlXkXvXqX_ a   .               o   d.UXKXUXUXUXUXUXUXUXPXUXeX&   .               X   H UXUXUXUXUXUXUXUXUXUXUXMXG.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXjXBX'.v <.  `.BXjXlXjXBX[.v 1.  ).BXjXlXkXvXqX_ a   .               o   d.UXKXUXUXUXUXUXUXUXPXUXeX&   .               X   H UXUXUXUXUXUXUXUXUXUXUXMXG.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXeXNXF.  `.BXjXlXlXxXrXNXJ.  ).BXjXlXkXvXqX_ a   .               o   d.UXKXUXUXUXUXUXUXUXPXUXeX&   .               X   H UXUXUXUXUXUXUXUXUXUXUXMXG.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXDXb.  `.BXjXlXlXlXkXDXm.  ).BXjXlXkXvXqX_ a   .               o   d.UXKXUXUXUXUXUXUXUXPXUXeX&   .               X   H UXUXUXUXUXUXUXUXUXUXUXMXG.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXgXAXm.  `.BXjXlXlXlXgXZXB.  ).BXjXlXkXvXqX_ a   .               o   d.UXKXUXUXUXUXUXUXUXPXUXeX&   .               X   H UXUXUXUXUXUXUXUXUXUXUXMXG.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXhXAXN.  '.BXjXlXlXlXhXAXV.  _.BXjXlXkXvXqX_ a   .               o   d.UXKXUXUXUXUXUXUXUXPXUXeX&   .               X   H UXUXUXUXUXUXUXUXUXUXUXMXG.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXgXDXl.  /.VXjXlXlXlXhXDXc.  !.VXjXlXkXvXqX_ a   .               o   d.UXKXUXUXUXUXUXUXUXPXUXeX&   .               X   H UXUXUXUXUXUXUXUXUXUXUXMXG.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXmXoX>.1XbXkXlXlXlXjXmX+X>.<XbXkXlXkXvXqX_ s   o . . . . . . . O   s.UXGXLXLXLXLXLXLXLXJXUXqX*   X . . . . . . . O   H UXLXLXLXLXLXLXLXLXLXUXbXG.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXmXJXvXkXlXlXlXlXlXkXmXJXbXkXlXlXkXvXqX_ u                       k.UXUXUXUXUXUXUXUXUXUXUXgX+                       G UXUXUXUXUXUXUXUXUXUXUXKXH.NXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXjXfXkXlXlXlXlXlXlXlXjXfXkXlXlXlXkXvXwX( n 7 q 0 0 0 0 0 0 0 w 2 <.*X|..X.X.X.X.X.X.X X#XP.p q e e e e e e e e r 6 I @XoXoXOXOXOXOXOXOXoX#X^.Z.BXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXhXkXlXlXlXlXkXvXrXR $.s.t.y.y.y.y.y.y.y.u.r...:.;.;.;.;.;.;.;.;.-.:.&.r ; < < < < < < < < < : k X                       j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXVXAXnXkXlXlXlXkXvXrXT %.f.i.p.p.p.p.p.p.i.a.t.*.j.f.f.f.f.f.f.f.f.f.h.r.;                       p #   . . . . . . . . o   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX:.p S.CXhXlXlXkXvXrXT $.d.u.i.i.i.i.i.i.i.i.r.%.a.u.i.i.i.i.i.i.i.u.p.9.<   X . . . . . . . X   s #   . . . . . . . . o   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCXY.    0.FXgXlXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXgXq U % w.DXgXlXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXhXFX1.o *X. 9.SXhXlXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXjXmX-XX F.LX  h.UXfXlXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXhXAXU   :.=.  m oXnXjXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXjXMX@.j d e   @ A.VXhXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX0X  0.HXgXlXlXkXvXrXT %.f.u.i.i.i.i.i.i.i.p.r.%.a.u.i.i.i.i.i.i.i.u.a.0.<   .               .   a @                   X   j.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhX$XwXcXkXlXlXkXvXrXE &.g.i.p.p.p.p.p.p.p.a.t.*.s.i.p.p.p.p.p.p.p.i.s.q.2   O o o o o o o o O   f % . o o o o o o o o +   k.AXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXNXvXkXlXlXlXkXvXeXJ X.i.w.e.e.e.e.e.e.e.r.0.o.y.e.e.e.e.e.e.e.e.e.t.5.#                       0                         s.SXhXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXkXlXlXlXlXkXcXyX<.5.r.w.e.e.e.e.e.e.e.e.w.6.e.e.e.e.e.e.e.e.e.e.e.q.o.{ } } } } } } } } } { $. .} } } } } } } } }  ./ K.BXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXmXnXvXvXvXvXvXvXvXvXvXvXbXnXvXvXvXvXvXvXvXvXvXvXvXbXVXCXCXCXCXCXCXCXCXCXCXCXNXVXCXCXCXCXCXCXCXCXCXVXCXbXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXhXhXhXhXhXhXhXhXhXhXhXjXjXhXhXhXhXhXhXhXhXhXhXhXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXjXlXlXlXlXlXlXjXhXkXlXlXlXlXlXlXlXhXjXlXlXlXlXlXlXjXhXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXFXBXkXlXlXlXlXjXmXGXnXjXlXlXlXlXlXkXCXBXkXlXlXlXlXkXVXFXxXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmXeXM. XMXkXlXlXjXBX<Xn.1XMXjXlXlXlXkXnX(.].vXkXlXlXkXBX}.C.iXbXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX6Xy Q w N.ZXhXjXNX{.2 K r %XmXjXlXhXBXoX  D ZXhXlXhXAXs.5 A N dXxXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX9X^.tXD y.DXhXjXBX`.N.UXy l.FXhXlXlXvXS V Y VXjXlXjXNXM.oXMX# =XMXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXPX/ 2 [.MXjXlXjXnXUXw.y iXcXkXhXDXr.#.Y.S PXgXlXlXjXAXKXP E NXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX&Xl.UX%.h FXhXlXjXVXs.u tXSXhXlXzXjX> V Z = [.MXjXkXlXvX_ L SXbXjXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnX,X9 N 9 l.VXjXhXCXI.  k K F.VXhXzXgXI.H.W 1 5XvXkXhXSX;.  H P $XmXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMXuXK.#XNXkXlXkXbX1XQ.R.A.:XbXkXlXzXVXKXeX$XVXjXlXkXvX+X!.P.H.eXcXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXcXZXbXjXlXlXlXkXnXCXBXSXmXkXlXlXlXjXfXlXmXjXlXlXlXkXNXVXVXAXvXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXMXSXlXlXlXlXlXjXmXGXnXhXlXlXlXlXkXcXFXnXkXlXlXlXlXjXBXGXvXjXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX/.k.jXzXlXlXjXNX{.5. XMXjXlXlXkXvXpXa.{.mXkXlXlXlXvXP.5.-XmXjXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXqX% $ aXcXkXjXVX!.: X.6 }.NXjXlXlXlX)   -.FXgXlXhXAXg.i -.4 1XnXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXFX( R x tXcXkXkXMXoX(.UXt b.DXhXlXxXiX2X_ *.GXhXlXkXcX<X1XG.k 5XbXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXP.V 3Xt hXxXkXlXjXMXUX+.c kXzXkXlXlXjXUXW &.GXhXlXlXgXUX6Xx S eXcXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSXJ 3 H   y.VXjXlXkXnX=.d sXmXjXlXlXlXhXDXW &.GXhXlXjXBXh.L.IX& j.GXgXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxX*X].k.= .XnXkXhXZXG.  l x V.CXhXlXlXhXGXE %.GXhXlXjXVXZ.5 d N 9XvXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXAXvX<XnXlXlXkXcXwX*X+X{.9XcXkXlXlXlXcX5X9XcXlXlXlXkXCXwXXXkXnXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXlXmXkXlXlXlXkXvXNXNXVXbXkXlXlXlXlXkXbXbXkXlXlXlXlXjXvXBXzXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXlXlXlXlXlXkXjXjXjXkXlXlXlXlXlXlXkXkXlXlXlXlXlXlXkXjXkXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXVXBXVXVXVXVXVXVXBXBXVXVXVXVXVXVXVXBXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXjXjXjXlXlXkXcXrX`.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.|. X X X X X X X|.|. X X X X X X|.XXjXzXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXzXMXBXBXxXlXjXBX|.Z ^ Q Q Q Q Q ! W R ! Q Q Q Q Q ! W m x c c c c c x M n x c c c c v k P dXxXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXzXhX;XoXOXaXxXjXBX.X^ j.d.d.d.d.d.g.r.6.h.d.d.d.d.d.g.y.>               3 -           .   h kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXNXoX: K Z $XMXgXBX XQ s.u.i.i.i.u.p.0.2.a.u.i.i.i.u.p.w.>   . . . . .   3 ;   . . . . o   h kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXhXSXD.f (.:XMXkXjXBX XQ s.i.i.i.i.i.a.0.3.s.u.i.i.i.u.p.w.>   .       .   2 ;   .       X   g kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXVX~.n ( 6 oXMXgXBX XQ s.i.i.i.i.i.a.0.3.s.u.i.i.i.i.p.w.>   .       .   2 ;   .       X   g kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXbX<X=XUXF ;.HXdXBX XQ s.i.i.i.i.i.a.0.3.s.u.i.i.i.i.p.w.>   .       .   2 ;   .       X   g kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXhXCXY.2 &.7 _.BXgXBX XQ s.u.i.i.i.u.a.0.2.a.u.i.i.i.u.p.w.>   .       .   3 ;   .       X   h kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXmX/.,.{.NXjXjXBX XQ d.i.i.i.i.i.a.q.3.s.i.i.i.i.i.a.w.-               < *               d kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXNXHXmXjXlXjXBX XQ a.u.u.u.u.u.p.9.2.a.y.u.u.u.y.i.0.8 & ; - - - ; & w 6 & - - - - : + v jXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXzXBXVXZXcXkXjXNXOXV 6 6 5 5 5 6 3 e s 3 6 5 5 5 6 3 u y < 4 3 3 3 4 < i e 1 3 3 3 3 5 ; N hXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXzXsX(.L.P.tXcXhXMX@Xn               # 1               = :               , &               d kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXBX}.= ` W *XmXgXMX+Xm . . . . . X   = 5   X . . . X   , 1   X . . . X   3 ;   . . . . o   h kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXhXSXC.p K.OXVXjXjXMX+Xm               * 4   .       .   > <   .       .   2 ;   .       X   g kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXNX{.R %., /.BXgXMX+Xm               * 4   .       .   > <   .       .   2 ;   .       X   g kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXnX&X.XUXG ;.HXdXMX+Xm               * 4   .       .   > <   .       .   2 ;   .       X   g kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXVX^., R e @XMXgXMX+Xm . . . . . .   = 5   X . . . X   , 1   . . . . X   3 ;   . . . . o   h kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXjXNX=Xz.,XMXjXjXMX@Xn               $ 2               ; :               < *               f kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXjXhXlXlXlXjXMXFXcXjXlXjXNX+XB < < < < < < : 9 e $ = * * * = $ 7 r : < < < < < ; t 4 % = * * * - o c jXzXkXlXlXlXlX",
"lXlXlXlXlXlXjXNXSXzXlXlXlXgXbXAXzXlXjXNX+XB , , , , , , < = ^.bXaXdXdXdXsXlX,X9 ; < , , , < - u 7XjXsXdXdXdXaXxX`.0XvXkXlXlXlXlX",
"lXlXlXlXlXjXVXoXA.gXzXlXjXBX+XC.fXxXjXMX@Xn                 -XUXUXUXUXUXUXUXcX*               2 AXUXUXUXUXUXUXUX>X7XbXkXlXlXlXlX",
"lXlXlXlXhXVX!., * qXvXgXBX).2 # 6XbXhXMX+Xm . . . . . . X   #XUXJXPXPXPXLXUXgX;   X . . . X   5 nXUXLXPXPXPXKXUX*X8XbXkXlXlXlXlX",
"lXlXlXlXkXbX=XP.u 0XvXjXbX-XY.y 5XbXhXMX+Xm             .   $XUXLXUXUXUXPXUXhX;   .       .   5 mXUXIXUXUXUXPXUX=X8XbXkXlXlXlXlX",
"lXlXlXlXlXhXFX&X6 qXvXkXhXSX>X5 7XbXhXMX+Xm             .   $XUXLXUXUXUXPXUXhX;   .       .   5 mXUXIXUXUXUXPXUX=X8XbXkXlXlXlXlX",
"lXlXlXlXlXjXMXoX9 qXvXkXkXmX%X8 7XbXhXMX+Xm             .   $XUXLXUXUXUXPXUXhX;   .       .   5 mXUXIXUXUXUXPXUX=X8XbXkXlXlXlXlX",
"lXlXlXlXlXjXBXoX< 0XvXkXjXNX%X, 6XbXhXMX+Xm . X . . . X X   #XUXJXPXPXPXKXUXfX;   X . . . X   6 bXUXKXLXLXLXJXUX&X8XbXkXlXlXlXlX",
"lXlXlXlXlXlXxXpXoXgXzXlXlXxXaXXXfXzXjXMX@Xn                 :XUXUXUXUXUXUXUXnX&               2 GXUXUXUXUXUXUXUX1X7XbXkXlXlXlXlX",
"lXlXlXlXlXlXlXxXBXzXlXlXlXkXjXMXzXlXjXNXOXC 8 8 8 8 8 8 8 4 G.7X;X>X>X>X:X2X{.r 1 5 4 4 4 5 < a  X:X*X=X=X=X*X,XL.wXvXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXjXlXlXlXkXzXGXnXjXlXjXBX XQ s.i.i.i.i.i.a.q.&.3.1.2.2.2.1.3.>.8 % - = = = - % q %               d kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXxXsX8.].MXjXjXBX XQ s.i.i.i.i.i.a.0.5.h.s.d.d.d.s.f.t.;               < ;   . . . . o   h kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXgXDX9.  6.GXgXjXBX XQ s.u.i.i.i.u.a.0.3.s.u.i.i.i.u.p.w.>   .       .   3 ;   .       X   h kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXVX.Xv I 1.GXgXjXBX XQ s.i.i.i.i.i.a.0.3.s.u.i.i.i.i.p.w.>   .       .   2 ;   .       X   g kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXmXN T.;.;.PXgXjXBX XQ s.i.i.i.i.i.a.0.3.s.u.i.i.i.i.p.w.>   .       .   2 ;   .       X   g kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXjXNXOX  G 1 8 3XnXgXBX XQ s.i.i.i.i.i.a.0.3.s.u.i.i.i.i.p.w.>   .       .   2 ;   .       X   g kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXxXaXXX%XS ( nXkXjXBX X! s.i.i.i.i.i.a.0.3.s.u.i.i.i.i.a.w.<   o X X X o   4 >   o X X X O   j kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXxXMXAXtXpXbXkXjXBX|.T s.i.i.i.i.i.a.9.1.s.u.i.i.i.u.p.q.#               = +               u kXzXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXhXvXcXkXlXjXMX@X} r.q.w.w.w.q.e.7.3.e.q.w.w.w.q.w.8.Z x v v v v v z S V x v v v v b j Q hXzXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXkXgXsXsXsXsXsXsXsXsXdXsXsXsXsXsXsXsXsXzXcXcXcXcXcXcXcXzXxXcXcXcXcXcXcXcXzXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXkXkXlXlXlXlXlXkXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXzXkXlXlXjXnXcXkXlXlXlXkXvXzXlXlXlXlXMXlXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcX-XhXvXkXkXMX5XrXmXkXlXkXvXwXdXzXlXzXvX;XzXcXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXp./ ..hXjXVXW.L ^ ;XmXgXVXOX% |.BXgXBX4.I =.cXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXj.T xXkXvX:XhXY (.CXjXkX<.P }.CXjXjX1X=XZ zXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzX X~.N 4XnXjXBX%.e.AXdXDXb.M S r.AXgXbXqXG .XBXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXi.E %.sXkXCXG.5 X.OXmXcX,X~.R M.CXgXVX` f 9.pXxXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXBXeXvXvXkXzXfXsX8XdXzXkXnXZXxXbXlXlXlXdXuX9XlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXDXnXjXzXkXMXSXSXvXkXzXjXmXZXlXlXlXkXZXCXAXzXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZX*.g.AXgXnX;X) 3.aXxXjXMXE.R wXvXhXNXK.' x.cXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZX.Xe 2.GXdXVXT.`.I I.AXgXvXQ.k -XMXjXvX^.y.H kXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXsXG ,.+.BXjXgXIX`.&.vXlXlXjXDX/ *XMXkXhXnXL.U iXcXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX9X2.P x lXjXBXQ.. >.3XbXkXkXvXJ &XMXhXMX-.-.S 8XbXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXHXiX1XmXjXbX:XE.K.5XvXkXlXzX#XpXxXkXcXyXG.5XmXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXxXnXjXlXkXnXAXSXbXkXlXlXlXMXxXkXlXkXcXSXbXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXkXjXlXkXlXjXhXhXkXlXkXkXkXhXjXkXkXkXjXgXjXkXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXhXjXlXlXlXvXvXvXvXvXvXvXvXvXvXvXvXvXnXnXnXnXnXnXnXnXnXnXnXnXbXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXkXbXSXCXlXzXjXr.>.3.2.2.2.1.2.2.2.2.2.2.-.*.*.*.*.*.=.*.*.*.=.#.8.hXzXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXvX4XP.(.kXzXgXO.3.9.8.7.0.:.3.9.8.8.8.9.3           >           a lXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXhXDXO.L F.xXzXgX=.y.d.a.a.d.9.t.d.a.a.a.s.8   X     . 3   .   X   g zXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXjXBXe.%.q.jXxXfX*.e.p.i.u.a.6.e.p.i.i.i.p.7   X     . 2       X   g zXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXnXF. Xb :XMXfX*.e.i.u.u.p.6.w.i.u.u.u.i.7   X .   . 2   . . o   g zXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXjXNXP.E x.bXlXgX*.u.d.s.s.f.9.y.f.s.s.s.d.5           <           d zXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXkXVXCXZXlXzXgX%.,.5.4.4.6.;.1.5.4.4.4.5.y & : ; ; : e ; ; ; > @ b lXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXwXwXlXlXlX` . # @ @ o 3 = O @ @ O - 5 $ * & & * 0 & & & = X x lXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXhXZXi.R g.kXlXlX_           : @         # ;           <           d zXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXhXAXX.! L.bXkXlX_   . . .   , $   . .   % >   .     . 2       X   g zXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXbXE..Xm ,XmXkX_   .   .   , #         $ >   .     . 2       X   g zXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXjXVXh.) +.dXxXlX_           > & . o o . * :           3 o o o +   h lXlXlXlXlXlX",
"lXlXlXlXlXlXhXhXlXzXxX#XsXvXkXlX` . @ + @ o 1             1 o @ + + # ,           t zXlXlXlXlXlX",
"lXlXlXlXlXlXAXZXkXlXkXPXAXjXzXlX' - 1 < 1 = l ).).).)._.^.f - 1 < 2 # o.XX/.).).`.K.iXcXlXlXlXlX",
"lXlXlXlXkXnXn.d.mXjXnXn.a.nXkXlX)           g UXUXUXUXUXUXt       X   y.UXUXUXUXUXsXwXvXlXlXlXlX",
"lXlXlXkXxXgX@.D MXlXgX#.S mXkXlX_   X . o   g JXLXKXKXPXSXy   X . O   0.UXGXLXJXUX8XeXvXlXlXlXlX",
"lXlXlXlXjXNX2X/ mXhXNX4X/ nXkXlX_   .   X   g IXUXIXIXUXHXy   X   O   q.UXKXUXPXUX0XeXvXlXlXlXlX",
"lXlXlXlXjXBXXXG MXhXNXOXF mXkXlX_   o X O   h KXPXLXLXUXDXy   X   O   9.UXFXKXHXUX8XeXvXlXlXlXlX",
"lXlXlXlXkXvXwXQ.cXkXcXqXE.xXlXlX(           p UXUXUXUXUXUXy   .   o   u.UXUXUXUXUXdXwXvXlXlXlXlX",
"lXlXlXlXlXkXcXVXkXlXjXCXDXjXzXjX .n C V C m T !.^.~.~.^.Q.g : 3 2 4 = ^ v.f.h.h.g.d.aXxXlXlXlXlX",
"lXlXlXlXlXlXkXjXlXjXmXoX3XvXzXfX=.d.l.j.j.z.q.3.9.7.7.7.9.7   o X . o ;           w xXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXjXNX,X  b.DXjXgX&.w.u.y.y.i.6.y.d.a.a.a.s.7   .       3 O O O @   j lXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlX,. .Z.FXjXgX*.e.p.i.i.a.7.e.p.i.i.i.p.7   .       2       X   g zXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXVX).z N ! VXkXgX*.e.p.i.i.a.7.e.p.i.i.i.p.8   o . . X 3 . . . o   h zXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXzXpX7Xy.n.BXkXgX&.r.a.p.i.s.7.r.a.p.p.p.a.3           >           a zXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXxXmXVXNXkXzXgX;.8.e.w.w.r.3.8.e.w.w.w.e.h 1 6 5 5 6 s 5 5 5 7 > Z lXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXjXjXlXlXlXtXqXwXwXwXwXwXwXwXwXwXwXwXyXuXyXuXuXuXyXuXuXuXuXyXuXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXvXvXvXvXvXvXvXvXvXvXvXvXcXcXcXcXcXcXcXcXcXcXcXcXcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXjXkXlXlXlXlXjXkXlXlXlXjXjXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXVXMXkXlXlXxXZXcXkXlXlXkXNXxXkXlXkXNXNXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxX}.=XbXkXxXdX~.uXvXkXkXbX#XuXxXkXbXoX#XmXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX%X@.T 1XcXVXz...X.bXgXCX#X* .XNXbX=X#.Q |.BXjXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX3XI 1XnXgXCX^.6.BXlXpX@.] _.CXjXzXjX#.2XnXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX}.0.I /.BXNXH.5 ~.zXmX$X_ s w.AXkXaXj $.fXzXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXfXM.I.cXjXmX!.d.H.kXlXzXNX`.5XvXvX7Xh.x.<XbXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXPXUXkXzXjXGXUXKXkXlXkXvXUXnXkXkXbXUXUXmXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNXXXj.nXjXnX&X1.XXnXjXbX<Xr.yXcXzXgXx.x.aXxXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXNX( S VXgXNXS.h.U bXhXmX`.f :XmXxX0Xj.F }.BXjXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXhXDXa.~ [ iXxXhXGXf.D.VXjXhXFXO.%XMXkXjXeX/ !.CXjXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmXU.<.z 8XzXZXu.3 C.kXlXjXMX} *XmXbX>XX.^ E.CXjXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXVXCXyXvXkXxX6X*X%XlXlXlXzXqXgXzXkXbX3X<XMXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXfXfXzXhXjXhXcXnXnXjXjXjXhXxXkXhXjXhXcXvXgXjXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXlXlXkXcXVXVXVXBXVXVXVXBXNXBXVXBXNXNXMXNXNXNXNXMXMXNXNXzXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXvXvXkXcXrX~./.^.^.^././.^.^./.^._.}.{.{.{.{.[.{.{.{.{.}.dXzXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXzXqX9XjXBX.XW *.#.#.$...O.$.#.@.-.D = 1 < , 3 0 > < < ; t eXvXkXlXlXlX",
"lXlXlXlXlXlXlXhXAXJ.J B.lXNXXX%.z.f.f.j.e.p.h.g.d.b.U         o ;         < tXcXkXlXlXlX",
"lXlXlXlXlXlXlXhXAXV.] v.kXNXXX+.d.y.u.p.7.e.i.u.t.j.P   o .   # ,   X X   3 rXvXkXlXlXlX",
"lXlXlXlXlXlXlXjXNX).L.F 2XSX.XO.d.y.y.i.6.w.i.y.t.h.P   X .   @ >   . X   3 rXvXkXlXlXlX",
"lXlXlXlXlXlXlXjXmX&XO.Z.cXMX.X%.c.g.g.k.e.a.j.h.f.n.U         o ;         1 rXcXkXlXlXlX",
"lXlXlXlXlXlXlXlXjXBXUXKXjXNX+X! O.......{ | .... .@.S = < , > 3 q : , < - y rXvXkXlXlXlX",
"lXlXlXlXlXlXlXkXcXrXR._.jXmX=X7         * X         < + O O o % 1 X + +   6 rXvXkXlXlXlX",
"lXlXlXlXlXlXlXhXFXl.c K.xXnX*X0   X X   > #   . . . <         O :         2 rXcXkXlXlXlX",
"lXlXlXlXlXlXlXjXVXR.y.<.uXNX*X0   . .   : @         <         @ >   . .   2 rXvXkXlXlXlX",
"lXlXlXlXlXlXlXjXBXQ.s.R 8XVX*X0   .     : & X O O O 2         + < X O +   6 rXvXkXlXlXlX",
"lXlXlXlXlXlXgXjXcXtXz.+XbXnX=Xq   o X   ;           = o . .   $ O         @ tXcXkXlXlXlX",
"lXlXlXlXkXcXGXvXkXxXUXKXgXMX&Xa : 1 1 - h k.h.h.f.b.~ & 2 < 1 : ;.c.g.h.j.i.qXvXkXlXlXlX",
"lXlXlXkXcXrXq.<XbXnXP.z.bXnX=X9     .   k UXUXUXUXUXu.  o   X   &XUXUXUXUXNX8XbXkXlXlXlX",
"lXlXlXjXbX<Xc E.ZXcXr.K nXnX*X0   X X   h KXKXJXFXUX8.  O   o   [.UXGXJXUXpX8XbXkXlXlXlX",
"lXlXlXlXgXLX8.U.ZXvXqX[ cXnX*X0   X o   j IXUXIXJXUX0.  O   o   }.UXKXPXUXdX8XbXkXlXlXlX",
"lXlXlXlXhXSX1.R.ZXvX,X{ vXnX=X9   . X   h UXUXUXIXUXq.  X        XUXIXUXUXgX8XbXkXlXlXlX",
"lXlXlXlXlXxXtXsXzXlXfXeXkXmX*Xq   o O   j CXZXCXNXUX8.  * $ &   ].UXSXFXIXuX8XbXkXlXlXlX",
"lXlXlXlXlXlXcXxXkXlXBXnXjXNXoX] 3.,.,.<.-.r.i.u.y.h.R @ > ; - , s e r t q l rXvXkXlXlXlX",
"lXlXlXlXlXlXkXkXkXNX! A.CXmXXX#.l.s.d.g.0.e.p.u.t.j.L         o *         ; tXcXkXlXlXlX",
"lXlXlXlXlXlXlXhXCXW.m V.SXnXXX+.d.y.u.p.7.r.p.i.y.k.I   o .   @ ,   X o   4 rXvXkXlXlXlX",
"lXlXlXlXlXlXkXxXsXH L O.VXmXXX@.f.u.i.a.8.r.p.i.y.k.I   O X   # ,   X o   4 rXcXkXlXlXlX",
"lXlXlXlXlXlXlXzXfX=Xr.f.NXMX.Xo.f.u.u.p.7.e.p.u.t.k.H           %         - rXvXkXlXlXlX",
"lXlXlXlXlXlXlXlXzXBXCXNXjXMX#X=.d.u.u.p.0.r.i.u.y.g.` w p i u d z y i p r n tXcXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXjXjXjXlXlXkXaXpXpXpXpXaXpXpXpXpXpXdXjXjXjXjXjXhXjXjXjXjXhXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXxXxXxXxXxXxXxXxXxXxXxXzXzXzXzXzXzXzXzXzXzXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXNXbXkXkXbXNXkXlXkXbXvXkXkXmXMXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlX%X0XxXcX6X&XvXjXbX9X9XcXvX<X:XvXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXkXxXdX6.,.mXxXE.} +XNXmX/ V.DXhXF.| 4XnXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXzXfXP.} lXnX$X=.eXDXH.v a.CXvX`.1.jXzXlXlXlX",
"lXlXlXlXlXlXlXlXlXkXcXuXr.Z.zXBXd.-.wXnX0XC.K.MXvX6.8.aXxXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXzXHXDXlXkXDXFXvXjXnXPXZXkXlXFXSXxXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXhXFXM.n.CXbXH.<.8XbXzX3.[.NXvXC.5.aXxXkXlXlX",
"lXlXlXlXlXlXlXlXlXkXnX3XH r.ZXhX8X1.-XnXBXt.G.SXjX<X_ :XmXkXlXlX",
"lXlXlXlXlXlXlXlXlXjXNXXX} -.nXVXp.! sXkXSXJ.P.ZXlXN.] -XMXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXnXcXuXlXlX2X&XyXzXlXuXpXlXzX8X3XcXjXlXlXlX",
"lXlXlXlXlXlXkXkXlXlXvXnXnXNXmXmXZXSXNXnXbXmXmXbXbXNXVXbXcXlXlXlX",
"lXlXlXlXlXkXcXMXzXxX0X-X:X;X:X:X-X-X-X1X6X5X5X5X5X5X5X4XyXxXlXlX",
"lXlXlXlXlXxXyX:XsXBXg.X.>.;.&.%.;.=.1.P 4 q 8 t r 9 e - x.AXhXlX",
"lXlXlXlXjXCX>.%.dXBXl.q.g.f.u.t.f.p.v.L       + o       s.DXgXlX",
"lXlXlXlXkXcXH.%.{.HXj.4.i.y.q.9.u.e.g.L   O   * %   +   f.DXgXlX",
"lXlXlXlXjXmXE.5.6XZXl.t.z.l.s.p.l.g.N.Y   X   % #   o   d.DXgXlX",
"lXlXlXlXlXkXZXCXxXNXs.F E T T R T Y Q v & : = 4 2 - <   j.SXhXlX",
"lXlXlXlXjXNXN.u.pXSX0.        X       * X .   & $   O   d.DXgXlX",
"lXlXlXlXjXMXt.-.2XGXq.  O . % = . o o :   .   & $   +   d.DXgXlX",
"lXlXlXkXhXbXT.[ [.PX0.      + #       =       $ +       s.DXgXlX",
"lXlXkXnXbXcX6X,XcXVXe.  * # : 3 = ; ; 5 $ % # , 2 = ,   j.SXhXlX",
"lXkXvX4X3XvXzX<XaXZXe.  * $ * :XNXgXGX5.  - O 8 tXbXzXkX1XxXlXlX",
"lXjXCXi.6.JX7XU ,XHX0.  .   . aXUXIXUXe.  O   < ZXUXUXUX9XlXlXlX",
"lXkXBX#X0.VXCX8.#XKXq.  + . + eXUXDXUX0.  +   1 vXIXHXGX6XzXlXlX",
"lXkXnX2XE.mXvXP.5XFX0.        sXUXUXUXt.  @   3 PXUXUXUXeXlXlXlX",
"lXlXkXcXMXjXvXDXkXBXs.G Q E T M.R.K.^.[ O , * 7 #.&.*.| U.BXjXlX",
"lXlXlXkXgXCX@X>.nXmXz.t.z.l.s.5.q.8.p.H   X   $         u.FXgXlX",
"lXlXlXlXzXhXo.( kXNXl.5.p.u.w.e.s.i.z.I   O   * - O %   g.DXhXlX",
"lXlXlXkXvX0X5.^ eXCXh.6.a.i.w.0.p.t.k.G       o .       p.FXgXlX",
"lXlXlXlXkXcXVXaXkXMXm.9.s.a.t.r.a.u.j.) 5 r q a i q y , n.AXhXlX",
"lXlXlXlXlXlXjXxXlXzXfXpXpXpXpXpXpXpXpXsXgXgXgXfXfXgXgXfXhXlXlXlX",
"lXlXlXlXlXlXlXkXlXlXzXcXxXxXxXxXxXxXcXxXzXxXxXxXxXxXzXxXzXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXxXsX=XhXvX,X8XxXbX7XdXvX>X8XcXkXlX",
"lXlXlXlXlXlXkXxXpX:.|.SXI.p.VX7X^ 6XVXP.s.MXjXlX",
"lXlXlXlXlXlXkXvXeX=.).LXa.g.HX).Y %XHXi.z.VXjXlX",
"lXlXlXlXlXlXlXzXdXeXlXzX5XrXlXnXcXhXxX4XrXzXlXlX",
"lXlXlXlXlXlXlXkXmXV.wXMX^.U.mXaXc.pXMX^.Y.mXkXlX",
"lXlXlXlXlXlXjXBX].z &XFXF.y.MXbX7.4XVXY.#.bXkXlX",
"lXlXlXlXlXlXkXxX8XA.1XVXv.U.cXcX}.eXnXR.I.cXkXlX",
"lXlXlXlXjXjXlXcXAXLXZXmXHXSXMXMXSXBXMXDXGXmXlXlX",
"lXlXlXkXNXmXxX0X|. XXXoX X.XoXOXoXOXOXoX X=XzXlX",
"lXlXkXmX].).DXI.O.5.,.-.1.6.' o # % : $   C mXkX",
"lXlXjXBXd.1.VXE.5.g.i.e.p.j.#.    . %     M MXjX",
"lXlXkXnX'.f.MXW.q.c.g.p.j.b.=.  X O * o   B MXjX",
"lXlXlXzXfXpXAXP.x A C A V Z b * & ; 1 =   D mXjX",
"lXlXjXVXg.f.HXG.      o     O o   o & X   B MXjX",
"lXlXgXmXF.%.MXK.  . O $     # X   X @     b MXjX",
"lXzXVXbX5X>XSXJ.. % % 0 7 7 0 & # % 0 9 : Y nXkX",
"zXhXR.fXiX).SXJ.  &   !.UXPX'.  &   (.UXAXuXsXxX",
"kXbX,.6XyX%.AXJ.  +   '.UXUXXX  o   [.UXUXgXsXxX",
"jXNX!.8XnXL.BXJ.      ].UXUX@X  @   $XUXUXmXaXxX",
"lXkXcXzXxXgXCXU.H ^ U g.W.~.t.+ - $ ~ -...w.xXlX",
"lXlXhXCXG.s.IXY.w.c.j.8.9.y...  . +       j NXjX",
"lXlXzXlX| =.KXI.<.p.w.0.i.h.O.      @     n MXjX",
"lXlXlXzXrX:XCX~.9.j.s.u.d.k.>.8 w r p e 2 Q mXkX",
"lXlXlXlXvXmXlXgXuXiXiXiXiXiXiXaXaXaXaXaXaXsXlXlX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXzXjXeXzXeXkXhXgXsXyXxXlX",
"lXlXlXlXxXaXi.fXx.tXz. X%XD.BXjX",
"lXlXlXlXzXjX-XhX.XgX;XrX4X>XbXkX",
"lXlXlXkXcXeXh.cXF.yXoX<X,XH.MXjX",
"lXlXlXjXcXiXR.vXW.gXwXyX7X{.mXjX",
"lXlXlXMXzXtXiX8XtX9XrXrXrXiXfXzX",
"lXlXkXU.iXf.3.5.e.o.; 5 5 % |.VX",
"lXlXzXN.5Xb.f.p.b.&.  o o   '.CX",
"lXlXkX+XzX] 9 k h p # = , o {.VX",
"kXcXxXy.rXJ         X X     _.ZX",
"xXiXdX2XlXR   H k.X.. < 6.5.:XmX",
"BXXX.X`.7XY   0.UX<X  4 UXUXhXlX",
"xXaXpXsXhX| , 1.hXZ.  5 T.~.6XbX",
"kXxXkXa.uXz.s.0.w.[         ).ZX",
"lXzXdXY.pXb.p.a.v.,.3 e y 4 .XBX",
"lXlXzXCXzXaXpXpXpXpXiXiXiXuXjXzX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
